@@ -1,5 +1,8 @@
 package HTML::Widgets::NavMenu::Predicate;
 
+use strict;
+use warnings;
+
 use base 'HTML::Widgets::NavMenu::Object';
 
 use base 'Class::Accessor';
@@ -8,7 +11,7 @@ __PACKAGE__->mk_accessors(
     qw(type bool regexp callback),
     );
 
-sub initialize
+sub _init
 {
     my $self = shift;
 
@@ -23,7 +26,7 @@ sub initialize
 
 my %true_vals = (map { $_ => 1 } (qw(1 yes true True)));
 
-sub is_true_bool
+sub _is_true_bool
 {
     my $self = shift;
     my $val = shift;
@@ -32,7 +35,7 @@ sub is_true_bool
 
 my %false_vals = (map { $_ => 1 } (qw(0 no false False)));
 
-sub is_false_bool
+sub _is_false_bool
 {
     my $self = shift;
     my $val = shift;
@@ -52,11 +55,11 @@ sub _get_normalized_spec
     {
         return +{ 'cb' => $spec };
     }
-    if ($self->is_true_bool($spec))
+    if ($self->_is_true_bool($spec))
     {
         return +{ 'bool' => 1, };
     }
-    if ($self->is_false_bool($spec))
+    if ($self->_is_false_bool($spec))
     {
         return +{ 'bool' => 0, };
     }
@@ -138,5 +141,33 @@ sub evaluate
     }
 }
 
+=head1 NAME
+
+HTML::Widgets::NavMenu::Predicate - a predicate object for 
+HTML::Widgets::NavMenu
+
+=head1 SYNOPSIS
+
+    my $pred = HTML::Widgets::NavMenu::Predicate->new('spec' => $spec);
+
+=head1 FUNCTIONS
+
+=head2 my $pred = HTML::Widgets::NavMenu::Predicate->new('spec' => $spec)
+
+Creates a new object.
+
+=head2 $pred->evaluate( 'path_info' => $path_info, 'current_host' => $current_host )
+
+Evaluates the predicate in the context of C<$path_info> and C<$current_host>
+and returns the result.
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2006 Shlomi Fish, all rights reserved.
+
+This program is released under the following license: MIT X11.
+
+=cut
+
 1;
 
