@@ -1,5 +1,8 @@
 package HTML::Widgets::NavMenu::Tree::Node;
 
+use strict;
+use warnings;
+
 use base 'HTML::Widgets::NavMenu::Object';
 
 use base 'Class::Accessor';
@@ -9,7 +12,18 @@ __PACKAGE__->mk_accessors(
     qw(separator show_always skip subs text title url url_is_abs url_type),
     );
 
-sub initialize
+=head1 NAME
+
+HTML::Widgets::NavMenu::Tree::Node - an iterator for HTML.
+
+=head1 SYNOPSIS
+
+For internal use only.
+
+=head1 METHODS
+=cut
+
+sub _init
 {
     my $self = shift;
 
@@ -18,6 +32,12 @@ sub initialize
     return $self;
 }
 
+=head2 $self->expand()
+
+Expands the node.
+
+=cut
+
 sub expand
 {
     my $self = shift;
@@ -25,6 +45,12 @@ sub expand
     return 0;
 }
 
+=head2 $self->mark_as_current()
+
+Marks the node as the current node.
+
+=cut
+
 sub mark_as_current
 {
     my $self = shift;
@@ -40,6 +66,12 @@ sub _process_new_sub
     $self->update_based_on_sub($sub);    
 }
 
+=head2 $self->update_based_on_sub
+
+Propagate changes.
+
+=cut
+
 sub update_based_on_sub
 {
     my $self = shift;
@@ -50,6 +82,12 @@ sub update_based_on_sub
     }    
 }
 
+=head2 $self->add_sub()
+
+Adds a new subroutine.
+
+=cut
+
 sub add_sub
 {
     my $self = shift;
@@ -59,6 +97,12 @@ sub add_sub
     return 0;
 }
 
+=head2 $self->get_nth_sub($idx)
+
+Get the $idx sub.
+
+=cut
+
 sub get_nth_sub
 {
     my $self = shift;
@@ -66,12 +110,18 @@ sub get_nth_sub
     return $self->subs()->[$idx];
 }
 
-sub num_subs
+sub _num_subs
 {
     my $self = shift;
     return scalar(@{$self->{'subs'}});
 }
 
+=head2 $self->list_regular_keys()
+
+Customisation to list the regular keys.
+
+=cut
+
 sub list_regular_keys
 {
     my $self = shift;
@@ -79,6 +129,12 @@ sub list_regular_keys
     return (qw(host rec_url_type role show_always text title url url_type));
 }
 
+=head2 $self->list_boolean_keys()
+
+Customisation to list the boolean keys.
+
+=cut
+
 sub list_boolean_keys
 {
     my $self = shift;
@@ -86,6 +142,12 @@ sub list_boolean_keys
     return (qw(hide separator skip url_is_abs));
 }
 
+=head2 $self->set_values_from_hash_ref($hash)
+
+Set the values from the hash ref.
+
+=cut
+
 sub set_values_from_hash_ref
 {
     my $self = shift;
@@ -108,4 +170,12 @@ sub set_values_from_hash_ref
     }
 }
 
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2006 Shlomi Fish, all rights reserved.
+
+This program is released under the following license: MIT X11.
+
+=cut
+
 1;
